Either<L, R> class abstract

An abstract class representing an either type, where the value can be either of type L or R.

Implementers

Constructors

Either()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<T>(T left(L), T right(R)) → T
Returns the result of applying either left or right function depending on whether the value is of type Left or Right.

Operators

operator ==(Object other) bool
The equality operator.
inherited