Left<L, R> class

A class representing the left value of the Either type.

Inheritance

Constructors

Left(L value)
Creates a new Left object with the given value of type L.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → L
The value of type L stored in the Left object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<T>(T left(L), T right(R)) → T
Returns the result of applying either left or right function depending on whether the value is of type Left or Right.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited