Left<L, R> constructor
Left<L, R> (
- L value
Creates a new Left object with the given value of type L.
Implementation
Left(this.value);
Creates a new Left object with the given value of type L.
Left(this.value);