Right<L, R> class

A class representing the right value of the Either type.

Inheritance

Constructors

Right(R value)
Creates a new Right object with the given value of type R.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → R
The value of type R stored in the Right object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<T>(T left(L), T right(R)) → T
Returns the result of applying either left or right function depending on whether the value is of type Left or Right.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited