Right<L, R> constructor
Right<L, R> (
- R value
Creates a new Right object with the given value of type R.
Implementation
Right(this.value);
Creates a new Right object with the given value of type R.
Right(this.value);