CategoryModel class

A model class representing a category.

Constructors

CategoryModel({required String name})
Creates a new CategoryModel instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the category.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns a string representation of the CategoryModel instance.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited