RatingModel class

A model class representing a rating.

Constructors

RatingModel({required num rate, required num count})
Creates a new RatingModel instance.
const
RatingModel.empty()
Creates an empty RatingModel instance with default values.
factory
RatingModel.fromJson(Map<String, dynamic> json)
Creates a RatingModel instance from a JSON object.
factory

Properties

count num
The number of ratings.
final
hashCode int
The hash code for this object.
no setterinherited
rate num
The average rating score.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited