ProductService class

Constructors

ProductService({required HTTPAdapter httpAdapter})

Properties

hashCode int
The hash code for this object.
no setterinherited
httpAdapter HTTPAdapter
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllProducts() Future<Either<List<ProductModel>, int>>
getProductsByCategory({required String category}) Future<Either<List<ProductModel>, int>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited