Right<L, R> class
A class representing the right value of the Either type.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
T> (T left(L), T right(R)) → T -
Returns the result of applying either
leftorrightfunction depending on whether the value is of type Left or Right.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited