HTTPAdapter class
A singleton class for handling HTTP requests.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dynamicRequest<
T> ({required String method, required String url, dynamic body, Map< String, String> ? addHeaders}) → Future<Either< T?, int> > - Sends a dynamic HTTP request.
-
get<
T> ({required String url, Map< String, dynamic> ? queryParameters, Map<String, String> ? headers}) → Future<Either< T?, int> > - Sends a GET request.
-
getResponse<
T> (HttpClientResponse response) → Future< Either< T?, int> > - Processes the HTTP response.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited